#!/bin/nawk -f
#
# Read the file of combined Ashtech and INS data computes the
# difference and the average.
#
# Input: 
#    Time Head   Unit
#     0.0 259.07 ASH
#     0.0 262.7 INS
#     1.0 258.91 ASH
#     1.0 262.6 INS
#
# Output:
#
# Time difference INS gyro  Ashtech
# 0.0 -3.37000000 14.900000 11.530000
# 1.0 -3.54000000 14.900000 11.360000
# 2.0 -3.33000000 14.800000 11.470000
#
# Output at end of file:
#
# Average error = -3.268552
# Max pos = 4.970000
# Max neg = -5.000000
#
BEGIN {
	sum = 0
	cnt = 0
	max_pos = 0
	max_neg = 0
}
{
	if ( $3 == "ASH") {
		ash_head = $2
		next
	}
	if ( $3 == "INS") {
		ins_head = $2
		if ( ash_head <= 360.) {
			error = (ash_head - ins_head)
			printf "%s %6.8f %f %f\n", $1, error , 
					ins_head, ash_head
			ash_head = 999
			if ( error > 5) next
			if ( error < -5) next
			sum += error
			cnt++
			if ( error > max_pos ) max_pos = error
			if ( error < max_neg ) max_neg = error
		}
	}
}
END {
	average = sum / cnt
	printf "Average error = %f\n",average
	printf "Max pos = %f\n", max_pos
	printf "Max neg = %f\n", max_neg
}
